#
# spec file for package lilo
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Url:            http://lilo.alioth.debian.org/

Name:           lilo
ExclusiveArch:  ppc ppc64 ppc64le %ix86 x86_64
%define yaboot_vers 22.8-r1190
%define ppc_version 22.8
Summary:        The Linux Loader, a Boot Menu
License:        GPL-2.0 and BSD-3-Clause
Group:          System/Boot
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Obsoletes:      quik
Obsoletes:      yaboot
%ifarch ppc ppc64
%if 0%{?suse_version} > 1020
BuildRequires:  dtc
%endif
Requires:       coreutils
Requires:       dosfstools
Requires:       gawk
Requires:       hfsutils
Requires:       sed
# for relinking the prep/chrp images in lilo
%ifarch ppc
Requires:       gcc
%endif
%ifarch ppc64
Requires:       gcc-32bit
%endif
# for nvram
%if 0%{?suse_version} > 1000
Requires:       powerpc-utils >= 1.2.6
%else
Requires:       util-linux
%endif
Requires:       binutils
Requires:       parted
%endif
%ifarch %ix86 x86_64
BuildRequires:  bin86
BuildRequires:  nasm
%endif
%ifarch %ix86
BuildRequires:  device-mapper
BuildRequires:  device-mapper-devel
%endif
%ifarch x86_64
BuildRequires:  device-mapper-32bit
BuildRequires:  glibc-devel-32bit glibc-32bit
# openSUSE 11.3 and SLE_11 do not have device-mapper-devel-32bit
%if 0%{?suse_version} != 1130 && 0%{?suse_version} != 1110
BuildRequires:  device-mapper-devel-32bit
%endif
BuildRequires:  gcc-32bit
%endif
%ifarch ppc64
BuildRequires:  gcc-32bit
%endif
# note: already outdated; download fresh sources from: https://alioth.debian.org/frs/?group_id=100507
Version:        23.2
Release:        87.5
Source0:        lilo-ppc-%{ppc_version}.tar.bz2
# From git repo at http://git.ozlabs.org/?p=yaboot.git
%ifarch ppc64le
Source1:        yaboot-%{yaboot_vers}-bin.tar.bz2
%else
Source1:        yaboot-%{yaboot_vers}.tar.bz2
%endif
Source86:       lilo-%{version}.tar.gz
Patch8601:      lilo.x86.mount_by_persistent_name.patch
Patch8602:      lilo.x86.array-bounds.patch
Patch8604:      lilo.x86.checkit.patch
Patch8605:      lilo-no-build-date.patch
Patch8607:      yaboot-libgcc.patch
Patch8608:      lilo-libgcc.patch
Patch8609:      lilo.ppc.ps3.patch
Patch8610:      lilo.src.Makefile.patch
Patch8611:      lilo.ppc-22.8.opal.patch
Patch8612:      lilo.ppc-kvm.patch
Patch8613:      lilo.gcc48.patch
Patch8614:      0001-Use-tftp-1M-blocksize.patch
# $Id: lilo.spec 1188 2008-12-09 14:29:53Z olh $

%description
LILO boots Linux from your hard drive. It can also boot other operating
systems, such as MS-DOS and OS/2, and can even boot DOS from the second
hard drive. The configuration file is /etc/lilo.conf.

The PowerPC variant can be used on new PowerMacs and CHRP machines.

The ix86 variant comes with Memtest86, offering an image that can be
booted to perform a memory test.

%prep
%setup -q -T -c -a 0 -a 1 -a 86
mv lilo-ppc-%{ppc_version} lilo.ppc
%ifarch ppc64le
mv yaboot-%{yaboot_vers}-bin yaboot
%else
mv yaboot-%{yaboot_vers} yaboot
%endif
pushd lilo-%{version}
%patch8601 -p1
%patch8602 -p1
%patch8604 -p1
%patch8605 -p1
%patch8610 -p1
%patch8613 -p1
popd
%ifnarch ppc64le
pushd yaboot
%patch8607 -p1
%patch8614 -p1
popd
%endif
pushd lilo.ppc
%patch8608 -p1
%patch8609 -p1
%patch8611 
%patch8612 -p1
popd

%build
%ifarch %ix86 x86_64
pushd lilo-%{version}
cflags="$RPM_OPT_FLAGS -fno-strict-aliasing -DLCF_DEVMAPPER"
%ifarch x86_64
cflags="$cflags -m32"
%endif
make CC="gcc $cflags" MAN_DIR=/usr/share/man all 
popd
# powerpc
%endif
%ifarch ppc ppc64
pushd yaboot
#
make clean
make DEBUG=1 VERSION=%{yaboot_vers}.SuSE yaboot HOSTCFLAGS="$RPM_OPT_FLAGS -U_FORTIFY_SOURCE -g"
mv second/yaboot yaboot.debug
mv second/yaboot.chrp yaboot.chrp.debug
#
make clean
make DEBUG=0 VERSION=%{yaboot_vers}.SuSE yaboot HOSTCFLAGS="$RPM_OPT_FLAGS -U_FORTIFY_SOURCE -g"
mv second/yaboot yaboot
mv second/yaboot.chrp yaboot.chrp
mv second/yaboot.a second/crt0.o .
#
popd
#
pushd lilo.ppc
pushd bootheader
make HOST_CFLAGS="$RPM_OPT_FLAGS -U_FORTIFY_SOURCE -g"
popd
%endif

%install
%ifarch %ix86 x86_64
pushd lilo-%{version}
make MAN_DIR=/usr/share/man install DESTDIR=$RPM_BUILD_ROOT
rm -rfv $RPM_BUILD_ROOT/boot
mkdir -p $RPM_BUILD_ROOT/boot
cp -av src/*.b $RPM_BUILD_ROOT/boot
popd
%else
# powerpc
# get rid of /usr/lib/rpm/brp-strip-debug 
# it kills the zImage.chrp-rs6k 
export NO_BRP_STRIP_DEBUG=true
# do not strip binaries, keep debug info
export NO_DEBUGINFO_STRIP_DEBUG=true
#
mkdir -p $RPM_BUILD_ROOT/lib/lilo/pmac
mkdir -p $RPM_BUILD_ROOT/lib/lilo/chrp
mkdir -p $RPM_BUILD_ROOT/sbin
mkdir -p $RPM_BUILD_ROOT/bin
mkdir -p $RPM_BUILD_ROOT/bin
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man8
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man5
mkdir -p $RPM_BUILD_ROOT%{_docdir}/lilo
pushd lilo.ppc
cp -av lilo.new $RPM_BUILD_ROOT/sbin/lilo
cp -av lilo-pmac.lib $RPM_BUILD_ROOT/lib/lilo/lilo-pmac.lib
cp -av lilo-chrp.lib $RPM_BUILD_ROOT/lib/lilo/lilo-chrp.lib
cp -av lilo-iseries.lib $RPM_BUILD_ROOT/lib/lilo/lilo-iseries.lib
cp -av show_of_path.sh $RPM_BUILD_ROOT/bin
cp -av Finder.bin $RPM_BUILD_ROOT/lib/lilo/pmac
cp -av System.bin $RPM_BUILD_ROOT/lib/lilo/pmac
cp -av os-badge-icon $RPM_BUILD_ROOT/lib/lilo/pmac
cp -av README* $RPM_BUILD_ROOT%{_docdir}/lilo/
cp -av COPYING $RPM_BUILD_ROOT%{_docdir}/lilo/
cp -av man/lilo.conf.5 $RPM_BUILD_ROOT%{_mandir}/man5
cp -av man/lilo.8 $RPM_BUILD_ROOT%{_mandir}/man8
cp -av man/show_of_path.sh.8 $RPM_BUILD_ROOT%{_mandir}/man8
%ifnarch ppc64le
pushd bootheader
make install DESTDIR=$RPM_BUILD_ROOT
popd
%endif
popd
pushd yaboot
cp -av yaboot.chrp* $RPM_BUILD_ROOT/lib/lilo/chrp
%ifnarch ppc64le
cp -av yaboot yaboot.debug $RPM_BUILD_ROOT/lib/lilo/pmac
cp -av crt0.o $RPM_BUILD_ROOT/lib/lilo/chrp/yaboot.crt0.o
cp -av ld.script $RPM_BUILD_ROOT/lib/lilo/chrp/yaboot.ld.script
cp -av yaboot.a $RPM_BUILD_ROOT/lib/lilo/chrp/
cp -av make_yaboot.sh $RPM_BUILD_ROOT/lib/lilo/scripts/
cp -av man/bootstrap.8 man/yaboot.8 $RPM_BUILD_ROOT%{_mandir}/man8
cp -av man/yaboot.conf.5 $RPM_BUILD_ROOT%{_mandir}/man5
popd
%endif
#powerpc
%endif

%triggerpostun  -- lilo < 0.0.10
# for manual updates
if [ -f /etc/lilo.conf.rpmsave -a ! -f /etc/lilo.conf ] ; then
mv -v /etc/lilo.conf.rpmsave /etc/lilo.conf
fi
exit 0

%files
%defattr (-,root,root)
%ifarch %ix86 x86_64
/sbin/*
/usr/sbin/*
/boot/*.b
%else
#powerpc
%dir /lib/lilo
%dir /lib/lilo/chrp
%dir /lib/lilo/pmac
%ifnarch ppc64le
%dir /lib/lilo/prep
%dir /lib/lilo/ps3
%dir /lib/lilo/common
%dir /lib/lilo/scripts
%dir /lib/lilo/utils
#
%attr(755,root,root) /bin/mkzimage_cmdline
%attr(755,root,root) %config /bin/mkzimage
%endif
%attr(755,root,root) %config /bin/show_of_path.sh
%ifarch ppc ppc64
%attr(644,root,root) /lib/lilo/pmac/yaboot*
%attr(644,root,root) /lib/lilo/ps3/*
%attr(644,root,root) /lib/lilo/*/*.o
%attr(644,root,root) /lib/lilo/*/*.a
%attr(644,root,root) %config /lib/lilo/*/*ld.script*
%attr(755,root,root) %config /lib/lilo/scripts/*.sh
%attr(755,root,root) /lib/lilo/utils/*
%endif
%attr(755,root,root) %config /lib/lilo/pmac/os-badge-icon
%attr(644,root,root) /lib/lilo/pmac/*.bin
%attr(644,root,root) %config /lib/lilo/lilo-*.lib
%attr(644,root,root) /lib/lilo/chrp/yaboot.chrp*
%attr(755,root,root) %config /sbin/lilo
%doc %{_docdir}/lilo
%endif
%doc %{_mandir}/*/*

%changelog
* Fri Dec 20 2013 dvaleev@suse.com
- Package ppc64 BE yaboot binary for ppc64le
* Wed Oct 30 2013 dvaleev@suse.com
- Use 1024 blocksize for tftp. openSUSE initrd is too big to fit
  32M limit
  + added 0001-Use-tftp-1M-blocksize.patch
* Thu Jul  4 2013 matz@suse.com
- Fix build with gcc 4.8: lilo.gcc48.patch
* Fri Apr 19 2013 dvaleev@suse.com
- Build with devmapper support (bnc#816102)
* Mon Oct  8 2012 dvaleev@suse.com
- refresh kvm patch (fix syntax errors)
* Tue Oct  2 2012 dvaleev@suse.com
- add gcc-32bit as BuildRequires for ppc64
  we need 32bit library to link against (bootloaders are always
  32bit)
* Fri Aug 10 2012 dvaleev@suse.com
- drop lilo.ppc.nvram-fix.patch. Use nvsetenv wrapper from
  powerpc-utils instead
- get OF path for virtio. Don't run nvsetenv if /dev/nvram is not
  available
- find SLOF disks, they are disk@id,lun
* Mon Mar 12 2012 dvaleev@suse.com
- Add support for PowerNV platform
* Fri Mar  2 2012 meissner@suse.de
- pass -m32 to print-gcc-lib , as the boot images are 32bit.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Dec 21 2011 aj@suse.de
- Fix yaboot download URL.
* Tue Nov 22 2011 dvaleev@suse.com
- fix ppc64 build, by do not using size optimization
* Fri Sep 23 2011 per@opensuse.org
- upgrade to lilo 23.2.  Amended mount_by_persistent_name patch so
  it applies, removed division-by-zero patch (code now in upstream),
  amended other patches to work with new src/ dir. Updated Makefile
  to skip hooks, images and samples. Updated spec to skip 'activate'
  which was removed from source package. Updated spec to not require
  device-mapper-devel-32bit for build.
  For a complete changelog for 22.8 to 23.2, see the tarball; lots of
  clean-up, optimization, removal of obsolete code etc. Some of the
  more significant changes are:
  - increase maximum number of sectors (MAX_SETUPSECS) for
    kernel setup code to 63.
  - support for newer MD RAID metadata format
  - support for root on LVM
  - allow spaces in boot menu
* Fri Jul  8 2011 dvaleev@novell.com
- fix ps3.dts compiling with new dtc version
* Thu Jun 30 2011 meissner@suse.de
- require just gcc, unversioned, and use `gcc -print-libgcc-file-name`
  in linking calls.
* Wed Jun 22 2011 meissner@suse.de
- also add the libgcc.a linking in the make*.sh lilo scripts
- build against 4.6 gcc, also require it during install
* Fri Mar  4 2011 estellnb@elstel.com
- include chain.b and other *.b-s
  for chainloading and for booting other OSes
  (resolves bnc#642401)
* Sun Feb 20 2011 meissner@suse.de
- make it build by explicitly linking libgcc.a
* Fri Feb 11 2011 dvaleev@novell.com
- don't try to set bootinfo-linux variable
  Not needed for fat boot partitions
* Thu Feb 10 2011 dvaleev@novell.com
- require powerpc-utils 1.2.6
- changed nvsetenv to nvram
* Thu Nov 18 2010 coolo@novell.com
- set SUSE_ASNEEDED=0 for powerpc
* Thu Sep 30 2010 stefan.fent@novell.com
- add device-mapper and device-mapper-devel (respective -32 bit
  for x86_64) to build with devicemapper supprt (bnc #642400)
* Mon Aug 30 2010 cristian.rodriguez@opensuse.org
- Do not include build dates
* Wed Feb  4 2009 olh@suse.de
- if tftp download fails in yaboot, close the device to release
  all resources.
  the ehea kernel driver can not use all required resources if
  they are still partly used by the firmware (bnc#468189)
* Tue Dec  9 2008 olh@suse.de
- handle short reads in of_read() in yaboot
  POWER4 firmware does not load more than 11MB at once (bnc#436064)
* Mon Dec  1 2008 olh@suse.de
- fix warning in other= section when calling lilo
* Mon Dec  1 2008 olh@suse.de
- the sysfs layout for iscsi changed, iscsi_connection is now
  a directory
* Mon Dec  1 2008 olh@suse.de
- handle EFIKA as chrp in mkzimage, the default ELF link address
  for pmac loads the zimage at the wrong memory location
* Mon Dec  1 2008 olh@suse.de
- fix typo in addnote detection
* Fri Nov 28 2008 olh@suse.de
- skip config file handling on PS3 because kboot.conf is used
* Tue Nov 25 2008 olh@suse.de
- update can_yaboot_read to handle bind mounts
  they return the same major:minor number as the underlying
  filesystem and overwrite the previous valid filesystem entry
  which incorrectly forces booting from a FAT filesystem
* Wed Nov 19 2008 olh@suse.de
- remove addnote again, it will be chrp-addnote in util-linux
* Wed Nov 19 2008 olh@suse.de
- show &device; as device-path if no devspec file is found
  by show_of_path.sh (bnc#439619 - LTC49387)
* Mon Nov 17 2008 olh@suse.de
- build addnote binary to the x86 lilo package, required for
  mkzimage usage in yast2-product-creator (bnc#443859)
* Mon Nov 17 2008 olh@suse.de
- failing to mount /proc is not fatal if mkzimage isc called with
  option --board
* Mon Nov 17 2008 olh@suse.de
- remove mknote usage from mkzimage for target pmac (bnc#443859)
* Mon Nov 17 2008 olh@suse.de
- remove LTC48297 debug output from yaboot
* Mon Nov 17 2008 olh@suse.de
- handle EFIKA5K2 in mkzimage
  the CHRP string disappeared from /proc/cpuinfo
* Fri Nov  7 2008 olh@suse.de
- remove RPA addnote change because older firmware versions can
  handle relocation properly (bnc#427960)
* Wed Nov  5 2008 olh@suse.de
- use initrd-size in yaboot.conf to make initrd memory allocation
  in yaboot more robust (bnc#441735)
- loop through all images in check_config_file()
* Fri Oct 24 2008 olh@suse.de
- handle ibmvfc in show_of_path.sh (bnc#438689 - LTC49376)
* Fri Oct 24 2008 olh@suse.de
- remove debug output from yaboot iscsi path (bnc#417539)
* Thu Oct 23 2008 olh@suse.de
- fix serial-number handling on pmac in yaboot
* Thu Oct 23 2008 olh@suse.de
- use BuildRequires gcc-32bit on x86_64 only with SuSE > 10.1
- remove unused BuildRequires libgcc42-32bit on x86_64
* Thu Oct 23 2008 olh@suse.de
- disable broken x86 checkit script
* Tue Oct 21 2008 olh@suse.de
- fix NULL pointer passed to strlen in yaboot when dumping pathname
* Mon Oct 20 2008 olh@suse.de
- update checks for CAS reboot (bnc#427960)
  one property is a string, another is an integer
* Sat Oct 18 2008 ro@suse.de
- update buildreqs for x86_64
* Wed Oct 15 2008 olh@suse.de
- print some system info in yaboot on startup
* Thu Oct  9 2008 olh@suse.de
- Avoid a division by zero on buggy BIOS (bnc#429544)
* Thu Oct  9 2008 olh@suse.de
- the ibm,client-architecture-support-reboot is in the /chosen node
  not in the /options node (bnc#427960)
* Mon Oct  6 2008 olh@suse.de
- assign tftp filename correctly if options are incomplete
* Thu Oct  2 2008 olh@suse.de
- handle short reads in yaboot ext2fs
* Thu Oct  2 2008 olh@suse.de
- increase initrd malloc chunksize from 4MB to 10MB
  if memory is fragmented, initrd allocation will fail
* Tue Sep 30 2008 olh@suse.de
- handle memory for initrd download correctly
* Mon Sep 29 2008 olh@suse.de
- do not force zImage if root is on iscsi (bnc#417539)
  yaboot can handle iscsi now
* Fri Sep 26 2008 olh@suse.de
- scan all partitions if booted from iscsi (bnc#417539)
* Thu Sep 25 2008 olh@suse.de
- bootheader: update RPA note in addnote to tell firmware to
  relocate itself to make room for the downloaded ELF binary
  there must be enough room for the TFTP download (bnc#427960)
* Thu Sep 25 2008 olh@suse.de
- bootheader: leave initrd where it is if the kernel has enough room
  at address 0x0 (bnc#427960)
* Fri Sep 19 2008 olh@suse.de
- rewrite /chosen/bootpath parser to support IPv6 TFTP (bnc#417538)
* Fri Sep  5 2008 olh@suse.de
- let yaboot boot SLES9 zImage files by allocating runtime memory at 4MB
* Fri Aug 29 2008 olh@suse.de
- change printf format strings in iseries-addRamDisk to u32
* Fri Aug 29 2008 olh@suse.de
- also allow ELF binaries with type ET_DYN, required for
  relocatable kernels (fate#304346)
* Fri Aug 29 2008 olh@suse.de
- add a message about timeout before calling udevsettle
* Fri Aug 29 2008 olh@suse.de
- require powerpc-utils only in SLES10 or later, for nvsetenv
* Fri Jul 25 2008 olh@suse.de
- use correct udevadm option for settle
* Tue Jul 22 2008 olh@suse.de
- fix incorrect variable size in iseries-addRamDisk
* Tue Jul 22 2008 olh@suse.de
- look also for CAS bootp reply if there are no device options
  in the bootpath
* Tue Jul 22 2008 olh@suse.de
- print tftp download rate, because CAS has a slow tftp client
* Fri Jul 18 2008 olh@suse.de
- fix a parser bug in CAS tftp options,
  use full options even if the firmware provided not all options
* Sun Jul 13 2008 olh@suse.de
-  openSuSE buildservice, unlike autobuild, can not handle two
  different arch specific packages with the same name:
  merge x86 lilo-22.8, drop all patches, except persistant devicename
  patch, none is required.
  drop unneeded lilo-doc package
* Mon Jul  7 2008 olh@suse.de
- increase yaboot tftp buffer size from 16 to 24MB,
  move load buffer from 42 to 24MB (fate#302195)
* Fri Jul  4 2008 olh@suse.de
- handle new obp-tftp interface in pSeries CAS firmware in yaboot
* Fri Jul  4 2008 olh@suse.de
- use either udevsettle or udevadm settle, or sleep
* Thu Jul  3 2008 olh@suse.de
- add md5sum check for vmlinuz/initrd to bootheader
  openfirmware truncates large bootfiles if real-base is at 32MB
* Wed Jul  2 2008 olh@suse.de
- mkzimage: handle missing 'Linux version' string in vmlinux binary
* Wed Jul  2 2008 olh@suse.de
- add ctrl c handling to bootheader, drops back into firmware
* Tue Jul  1 2008 olh@suse.de
- handle also -1 as claim error value in bootheader
* Tue Jul  1 2008 olh@suse.de
- handle gzipped vmlinux files in mkzimage
* Tue Jul  1 2008 olh@suse.de
- change chrp link address to 64MB, move OF real-base to 32MB
* Tue Jul  1 2008 olh@suse.de
- handle sas devices on Cell blades (bnc#390804 - LTC45678)
* Tue Jun 24 2008 olh@suse.de
- fix size of hvReleaseData in iseries-addRamDisk
* Fri Jun 20 2008 olh@suse.de
- fix show_of_path.sh to check for existance of /sys/block/*/*/dev
* Mon Jun  2 2008 olh@suse.de
- handle Efika as pegaos to allow bootloader configuration
  during installation (bnc#376310)
* Thu Mar 20 2008 olh@suse.de
- use zimage instead of yaboot if the boot= device points to a
  physical device and the default image= is on iscsi (bnc#372716)
* Thu Mar 20 2008 olh@suse.de
- fix uninitialized variable in ps3/gunzip_util.c
* Fri Mar 14 2008 olh@suse.de
- use udevsettle to wait for all pending background events
  udev will remove and add identical device nodes at random times
  (bnc#369834 - LTC43004)
* Thu Feb 14 2008 olh@suse.de
- make dtc optional during build
* Wed Jan 30 2008 sassmann@suse.de
- change MCONFIG to search for includes in local directory first
- add make_zimage_ps3.sh to build ps3 zImage
- new directory ps3 containing all files for building ps3 zImage
- add dtc to BuildRequires in spec file
- add make_zimage_ps3.sh to scripts Makefile
* Tue Jan 29 2008 olh@suse.de
- mark Emulex HBA adapter 0xfa00 as tested in show_of_path.sh
* Thu Jan 17 2008 olh@suse.de
- add debug output to TFTP download function (350212)
* Wed Jan 16 2008 olh@suse.de
- boot the same kernel if the pSeries CSA has to reboot to
  reconfigure the device-tree (353676 - LTC34053)
* Wed Jan 16 2008 olh@suse.de
- add functions to access /options/ properties to yaboot (353676)
* Tue Jan 15 2008 olh@suse.de
- add debug output to ELF read functions (350212)
* Mon Jan  7 2008 olh@suse.de
- replace ! in kernel device name with / to fix install on iseries
* Tue Nov 13 2007 olh@suse.de
- search for yaboot.conf-xx-xx-xx-xx-xx-xx on the tftp server
  zImage.initrd is now too large, so yaboot has to be used to load
  files from network (feat. 302195)
* Tue Nov  6 2007 olh@suse.de
- Fixed issue with SAS devices on different topologies and non-zero
  luns (338642 - LTC39882)
* Tue Nov  6 2007 olh@suse.de
- format the hfs boot partition if the size is less than 1MB (338300)
  remove old vmlinux.00N files
* Fri Sep 14 2007 olh@suse.de
- change the link address of yaboot and the chrp zImage from 64k
  to 256k to fix the boot binary with SLOF on Cell
* Tue Sep 11 2007 olh@suse.de
- add quotes about shell variables, and handle missing initrd
* Tue Aug 28 2007 olh@suse.de
- add a timeout=20 to initial kboot.conf on PS3
* Tue Aug 28 2007 olh@suse.de
- handle iSeries kernel slots in collect_path_info
* Thu Aug 23 2007 olh@suse.de
- fix variable assignment in lilo-pmac.lib to fix 'copy' option
  for root on lvm
* Thu Aug 23 2007 olh@suse.de
- handle the sysfs layout of the week: /sys/block contains symlinks
* Thu Aug 23 2007 olh@suse.de
- implement the lilo -R 'boot once' functionality (268527)
* Fri Aug 17 2007 olh@suse.de
- recognize the lilo -R "boot once" cmdline option
* Fri Aug 17 2007 olh@suse.de
- handle the sysfs layout of the week: /sys/block may be a symlink
* Fri Aug 17 2007 olh@suse.de
- handle pata_via on pegasos
* Mon Aug 13 2007 olh@suse.de
- change the fixed malloc buffer location to a dynamic one
  to allow booting with yaboot on efika
* Mon Aug 13 2007 olh@suse.de
- link yaboot at 64k
* Mon Aug 13 2007 olh@suse.de
- increase yaboot tftp buffer size from 12 to 16MB (feat. 302195)
* Mon Jul 30 2007 olh@suse.de
- use &device; instead of full path for image/initrd= on pmac (194118)
* Mon Jul 30 2007 olh@suse.de
- reformat shell scripts  for ts=4
* Mon Jul 30 2007 olh@suse.de
- add vim: ts=4 to shell scripts
* Fri Jul 27 2007 olh@suse.de
- remove duplicate global initrd= from yaboot.conf on pmac
* Fri Jul 27 2007 olh@suse.de
- fix of by one in lilo check_config_file function
* Fri Jul 27 2007 olh@suse.de
- use &device; instead of full path for other= on pmac (194118)
* Fri Jul 27 2007 olh@suse.de
- add get_relative_path_on_filesystem function to lilo
* Fri Jul 27 2007 olh@suse.de
- fix escape in bootinfo-linux string
* Fri Jul 27 2007 olh@suse.de
- remove unneeded test -f checks from lilo
* Thu Jul 26 2007 olh@suse.de
- add collect_path_info function to lilo, for simpler location matching
* Thu Jul 26 2007 olh@suse.de
- initialize and document global arrays in lilo
* Thu Jul 26 2007 olh@suse.de
- remove the global option 'force', it was used for firmware check
* Thu Jul 26 2007 olh@suse.de
- do not create a temporary /etc/yaboot.conf, use /etc as pathinfo
* Thu Jul 26 2007 olh@suse.de
- remove unused chrp firmware check
* Thu Jul 26 2007 olh@suse.de
- required a boot= in lilo.conf on chrp/prep, so that fdisk does
  not pick up an 41 PReP boot partition on a random disk
* Wed Jul 25 2007 olh@suse.de
- use stat in function can_yaboot_read
* Wed Jul 25 2007 olh@suse.de
- use stat -L
* Tue Jul 17 2007 olh@suse.de
- handle empty missing boot= on PS3 correctly
* Mon Jul 16 2007 olh@suse.de
- handle mptsas device in show_of_path.sh (290871 - LTC36211)
* Fri Jul  6 2007 olh@suse.de
- export TERM=dumb to fix parted --version parsing (289049)
* Tue Jul  3 2007 olh@suse.de
- remove set -/+ in lilo-chrp.lib
* Mon Jul  2 2007 olh@suse.de
- change lilo error 'ist not a regular file' to -ENOENT
* Mon Jul  2 2007 olh@suse.de
- use $STAT_CMD also in ps3 code
* Mon Jul  2 2007 olh@suse.de
- recognize also model SonyPS3, compatible sony,ps3
* Mon Jul  2 2007 olh@suse.de
- use stat -c %%s instead of wc -c to get filesize
* Mon Jul  2 2007 olh@suse.de
- remove shebang from bash library
* Mon Jul  2 2007 olh@suse.de
- use OUTPUT_ARCH(powerpc:common) in ld scripts for 64bit compiles
* Thu May 10 2007 sassmann@suse.de
- added support for ps3 in lilo.new
* Wed May  2 2007 olh@suse.de
- if the ELF sections in the linker script get renamed, the ld calls
  must be updated as well.
* Mon Apr 30 2007 olh@suse.de
- rename the ELF sections for kernel to match the mainline section
  names
* Wed Apr 25 2007 olh@suse.de
- remove :suseboot:yaboot.cnf, to force yaboot.conf
* Wed Apr 25 2007 olh@suse.de
- define a function warning() in show_of_path. (267871)
  define error() function before use.
* Wed Apr 25 2007 olh@suse.de
- update to mkzimage ld scripts to provide an ELF section for
  the compressed vmlinux and the initrd, to make it possible to
  extract the encapsulated files from the inst32/inst64 image again.
* Tue Apr  3 2007 olh@suse.de
- do not use ls -s to get the filesize, use wc -c instead
  ls reports not enough blocks for a sparse file
* Tue Apr  3 2007 olh@suse.de
- fix path pattern in is_on_iscsi
* Tue Apr  3 2007 olh@suse.de
- fix logic error in is_on_iscsi() (260223)
* Tue Apr  3 2007 olh@suse.de
- handle empty gateway in iscsi path (260089 - LTC33555)
* Tue Apr  3 2007 olh@suse.de
- parted --version output changed with 1.8
* Wed Mar 28 2007 olh@suse.de
- remove obsolete SLOF warning from lilo
* Sun Mar 25 2007 olh@suse.de
- use a zImage instead of yaboot with root on iscsi (246077 - LTC32118)
* Tue Mar 20 2007 olh@suse.de
- more iscsi device path handling (246077 - LTC32118)
  the firmware can not read from filesystems, remove all parsing code
* Tue Mar 20 2007 olh@suse.de
- handle new iscsi device type as block device in yaboot
* Mon Mar 19 2007 olh@suse.de
- detect iscsi lun in show_of_path (250969 - LTC32649)
* Mon Mar 12 2007 olh@suse.de
- better fix for iscsi device-path handling (246077 - LTC32118)
* Mon Mar  5 2007 olh@suse.de
- remove FAT16 warning from yaboot of_open routine (246077 - LTC32118)
* Fri Feb 23 2007 olh@suse.de
- document the clone= feature in lilo.conf(5)
* Thu Feb 22 2007 olh@suse.de
- move the evms hack before the mkfs.msdos call and update the
  comment to match the quality of the hack (247739)
* Fri Feb 16 2007 olh@suse.de
- add a label to FAT partitions to keep track where the bootloader
  came from
* Thu Feb 15 2007 olh@suse.de
- use built-in yaboot.conf for logical msdos partitions
  (173487/244397 - LTC31957)
* Sat Feb 10 2007 olh@suse.de
- do not read past the end of an ext2 partition
* Sat Feb 10 2007 olh@suse.de
- remove libext2fs.a from yaboot sources and build ext2 support
  from source (e2fsprogs-1.38) to simplify debugging (243911 - LTC31899)
* Mon Feb  5 2007 olh@suse.de
- set partition when booting from iscsi (237543- LTC31266)
* Tue Jan 30 2007 olh@suse.de
- increase the append= size from 200 to 512 chars in yaboot
* Fri Jan 26 2007 olh@suse.de
- /etc/initiatorname.iscsi moved to /etc/iscsi/initiatorname.iscsi
  (238738)
* Mon Jan 15 2007 olh@suse.de
- print newline after wrong label in yaboot label tab completion
* Tue Jan  9 2007 olh@suse.de
- consider also 0x6 FAT partitions on an msdos partition table
  in yaboot (230451/232821 - LTC30431/30708)
* Tue Jan  9 2007 olh@suse.de
- make removing empty /etc/yaboot.conf less verbose (232821 - LTC30708)
* Thu Dec 14 2006 olh@suse.de
- add make HARD_CODED_BOOTPATH=ofpath to yaboot make flags
* Mon Dec 11 2006 olh@suse.de
- relax SLOF check, just print some warning
* Fri Dec  8 2006 olh@suse.de
- recognize iscsi boots in yaboot (218773 - LTC28334)
* Fri Dec  8 2006 olh@suse.de
- recognize iscsi volumes with static ipv4 settings in show_of_path.sh
  (218773 - LTC28334)
* Tue Dec  5 2006 olh@suse.de
- remove empty /etc/yaboot.conf (170338)
* Mon Dec  4 2006 olh@suse.de
- add prom_getproplen_chosen to yaboot
* Mon Nov 27 2006 olh@suse.de
- reject Cell SLOF firmware, its not ready for primetime.
* Mon Nov 27 2006 olh@suse.de
- cell firmware can not yet resolve aliases, give better error msg
* Mon Nov 27 2006 olh@suse.de
- fix ' is is ' typo in yaboot help text
* Wed Nov 22 2006 olh@suse.de
- print trailing spaces only for the first two labels to avoid
  line wraps on 80x25 displays
* Wed Nov 22 2006 olh@suse.de
- handle malloc errors in yaboot.conf parser
  reduce useless debug output
* Sun Nov 19 2006 olh@suse.de
- rm -rf needs proc now, mount proc in mkzimage
* Sun Nov 19 2006 olh@suse.de
- fix another missing newline in yaboots label tab completion
* Tue Nov 14 2006 olh@suse.de
- update the yaboot 'help' text
* Tue Nov 14 2006 olh@suse.de
- handle load errors in yaboot, stop after the first error
  ramdisk loading is not fatal.
* Tue Nov 14 2006 olh@suse.de
- correct newline printing in yaboots label tab completion
* Tue Nov 14 2006 jplack@suse.de
- do hformat HFS partition if mount fails (#118023)
- use &device; instead of full of path in os-chooser (#194118)
- make timeout to select macos/linux boot configurable (#118776)
- copy global 'initrd=/boot/initrd' to boot device for pmac_old and
  pmac_new (#177481)
- bump version to 10.1.21
* Mon Nov 13 2006 olh@suse.de
- handle second ide port and cdrom device paths on pegasos (218692)
* Mon Nov 13 2006 olh@suse.de
- implement tab completion for yaboot.conf section label names
* Tue Nov  7 2006 olh@suse.de
- remove chmod calls in install section, permissions come via files
* Tue Nov  7 2006 olh@suse.de
- drop /sbin/lilo.old, its only purpose was the keyboard handling
  in os-chooser on firstgen iMac
* Tue Nov  7 2006 olh@suse.de
- keep a copy of local modifications to bash script libraries
* Tue Nov  7 2006 olh@suse.de
- do not use find-device?, it is not available in the firmware
  of the firstgen newworlds
* Tue Nov  7 2006 olh@suse.de
- use 'f' instead of 'h#f' to assign background-color
  the firmware in the firstgen newworlds does not handle it
* Thu Nov  2 2006 olh@suse.de
- fix duplicate default= lines in yaboot.conf if macos is
  configured as default in lilo.conf
* Wed Nov  1 2006 olh@suse.de
- set the os-chooser timeout from 3 to 5 seconds to fix slow monitors
* Wed Nov  1 2006 olh@suse.de
- use new Forth script for all Macs
* Wed Nov  1 2006 olh@suse.de
- set the color map also in the new Forth script
* Tue Oct 31 2006 olh@suse.de
- open output-device in yaboot and remove yaboot,do-open-screen handling
  leave the output-device alone if yaboot,do-not-open-screen exists
* Tue Oct 31 2006 olh@suse.de
- use the stdout ihandle in yaboot to setup the color map
* Tue Oct 31 2006 olh@suse.de
- use a different Forth script for MacRISC[34] to open the screen
* Mon Oct 30 2006 olh@suse.de
- use load/go in os-chooser instead of boot eval in linux only config
* Mon Oct 30 2006 olh@suse.de
- encode foreground-color in hex in os-chooser
* Mon Oct 30 2006 olh@suse.de
- handle no monitor connected on G5 with nvidia card in os-chooser
* Mon Oct 30 2006 olh@suse.de
- let yaboot run 'output-device output' if no yaboot,do-not-open-screen
  exists, or if yaboot,do-open-screen property exists in /chosen
* Mon Oct 30 2006 olh@suse.de
- option no_os_chooser does now only load and start yaboot
  it will not open the screen with " screen" output
* Mon Oct 30 2006 olh@suse.de
- use cat instead of echo to generate the pmac os-chooser script
* Mon Oct 30 2006 olh@suse.de
- no subshell for string assignment for pmac os-chooser
* Mon Oct 30 2006 olh@suse.de
- change pmac os-chooser hint from linux to Linux
* Mon Oct 30 2006 olh@suse.de
- fix weird loop handling in running_on_pmac_new
* Sun Oct 29 2006 olh@suse.de
- setprop takes a const *buf
* Fri Oct 27 2006 olh@suse.de
- move and resize the yaboot internal malloc area (215616)
* Tue Oct 24 2006 olh@suse.de
- temporary reverse the meaning of the lilo.conf  'no_os_chooser'
  option to test the new output-device code
  other= will currently only work when no_os_chooser is specified
* Tue Oct 24 2006 olh@suse.de
- open the output-device on pmac in yaboot when a monitor is connected
* Tue Oct 24 2006 olh@suse.de
- add a getproplen call to yaboot and bootheader
* Tue Oct 24 2006 olh@suse.de
- lilo requires parted
* Mon Oct 23 2006 olh@suse.de
- add some support for pegaos to lilo (205550)
* Fri Oct 20 2006 olh@suse.de
- fix infinite loop due to unaligned section data in prep bootheader
* Fri Oct 20 2006 olh@suse.de
- revert parts of last change
  yaboot will always start counting at 1 on amiga partition tables
* Thu Oct 19 2006 olh@suse.de
- handle amiga partition number offset correctly on pegasos
* Sat Oct 14 2006 olh@suse.de
- open the output-device on pmac in yaboot, except on G5
* Tue Oct 10 2006 olh@suse.de
- rm -rf fails with new sys*at syscalls if /proc is not mounted
* Tue Sep 19 2006 olh@suse.de
- the filesystem detection update broke CD booting, handle the case
  when no usable partitions were found by using the OF driver (206774)
* Fri Sep 15 2006 olh@suse.de
- yaboot_start never returns, update functions to return void
* Mon Sep 11 2006 jplack@suse.de
- change option no-os-chooser to no_os_chooser to be consistend
* Sat Sep  9 2006 olh@suse.de
- remove 0x prefix from debug output in bootheader
* Sat Sep  9 2006 olh@suse.de
- fix printf format strings in bootheader
* Sat Sep  9 2006 olh@suse.de
- mark md5 sum buffers as unsigned in yaboot to fix compile
  with -fsigned-char
* Sat Sep  9 2006 olh@suse.de
- allow compilation with compilers that do not understand -m32
* Sat Sep  9 2006 olh@suse.de
- fix duplicate entries in rpm filelist
* Sun Aug 27 2006 olh@suse.de
- remove unused option progressbar from lilo
* Sun Aug 27 2006 olh@suse.de
- compile yaboot with -mcpu=powerpc to reduce binary size
* Sat Aug 26 2006 olh@suse.de
- introduce lilo.conf option optional to skip unavailable kernels
  (202072)
* Sat Aug 26 2006 olh@suse.de
- introduce lilo.conf option no-os-chooser for headless G5 crash
  (202069)
* Sat Aug 26 2006 olh@suse.de
- add asm libgcc functions to remove libgcc.a usage
* Sat Aug 26 2006 olh@suse.de
- change static buffers to dynamically allocated ones in yaboot_text_ui
* Sat Aug 26 2006 olh@suse.de
- fs_t->open is always called with a valid partition in yaboot
* Sat Aug 26 2006 olh@suse.de
- use a shared printf_buf for prom_v{f,}printf in yaboot
* Sat Aug 26 2006 olh@suse.de
- remove unused /chosen/memory usage from yaboot
* Sat Aug 26 2006 olh@suse.de
- merge fs.c into file.c in yaboot
* Fri Aug 25 2006 olh@suse.de
- fix and simplify the filesystem detection in yaboot in file_block_open
* Fri Aug 25 2006 olh@suse.de
- parted print has now a space before the partition number in parted
  version 1.7. Remove it leading spaces for partition numbers (196212)
* Fri Aug 18 2006 olh@suse.de
- fill mem region returned by malloc with 'Z'
* Fri Aug 18 2006 olh@suse.de
- run indent in yaboot sources
* Wed Jul 26 2006 olh@suse.de
- read /proc/device-tree/device_type instead of device-type (#177314)
* Mon Jul 17 2006 olh@suse.de
- handle IDE device_type spi on pegasos in show_of_path.sh
* Mon Jul 17 2006 olh@suse.de
- do not use the firmware filesystem driver in yaboot unless
  it is a mac disk label. pegasos firmware behaves similar to
  chrp as described in bug #136537
* Mon Jul 17 2006 olh@suse.de
- handle pegasos return value -2 from read stdin in yaboot
* Mon Jun 12 2006 jplack@suse.de
- added sas support on Power6, patch by Brian King (#183466)
- bump version to 10.1.14
* Wed May 24 2006 jplack@suse.de
- do enhance detection for sub-architecture (#177314)
- handle global initrd option correctly with full OF path (#177481)
- bump version to 10.1.13
* Mon May 22 2006 olh@suse.de
- add a man page for show_of_path.sh
* Wed May 17 2006 olh@suse.de
- record vmlinux/initrd in /chosen/yaboot,image and yaboot,initrd
* Wed May 17 2006 olh@suse.de
- number logical msdos partitions correctly in yaboot
  if there is more than one logical partition, only the first one
  was considered because the loop was exited early
* Fri May 12 2006 jplack@suse.de
- Mark Emulex FC HBA/0xFD00 as tested (#163786)
* Sat May  6 2006 olh@suse.de
- do not print a NUL char after every newline in yaboot
* Wed May  3 2006 olh@suse.de
- let yaboot start vmlinux download even if no filename is specified
  allows load files from network via 'net:'
* Wed May  3 2006 olh@suse.de
- parse net path properly in yaboot on pseries, there is usually
  nothing after the device part. avoid operations on NULL pointer
* Wed May  3 2006 olh@suse.de
- initrd= can now be specified on the yaboot boot: prompt (100213)
* Mon May  1 2006 olh@suse.de
- remove the code that clears boot-file. yaboot did not look at
  /chosen/bootargs for a long time, now it may look for conf=
* Sat Apr 29 2006 olh@suse.de
- do not let OpenFirmware read from msdos partitions unless type
  is 0x6 (136537 - LTC20058)
* Sun Apr 23 2006 olh@suse.de
- fix unterminated string in enet:bootp bootpath handling in yaboot
* Sun Apr 23 2006 olh@suse.de
- fix strlen(NULL) in imagepath_to_path_description in yaboot
* Fri Apr 21 2006 olh@suse.de
- fix cross references in mkzimage man page
* Tue Apr 18 2006 olh@suse.de
- add a lilo manpage
* Tue Apr 18 2006 olh@suse.de
- remove dead sysmap= code from lilo
* Tue Apr 18 2006 olh@suse.de
- some fixes for yaboot.conf man page, document image[XXbit]=
* Mon Apr 10 2006 olh@suse.de
- provide a lilo.conf manpage
* Mon Apr 10 2006 jplack@suse.de
- copy image/initrd if of_path is empty/invalid (#164540)
* Mon Apr 10 2006 olh@suse.de
- add an option --help to lilo
* Mon Apr 10 2006 olh@suse.de
- add an option --version|-v to lilo
* Mon Apr 10 2006 olh@suse.de
- remove dead yast1 option --lilo-rootdrive from lilo script
* Mon Apr 10 2006 olh@suse.de
- update lilo --get-arch code, to recognize more board types
  handle Maple bases boards as chrp, handle Pegasos2 as pegasos
* Mon Apr 10 2006 olh@suse.de
- remove the unused variable COPY_BOOT_FILES from lilo
* Sun Apr  9 2006 olh@suse.de
- provide manpages for yaboot, yaboot.conf and boostrap
* Fri Apr  7 2006 olh@suse.de
- add script to relink yaboot at runtime to link a yaboot.conf
  into the yaboot binary.
  required for disks with more than one root partition
* Fri Apr  7 2006 olh@suse.de
- use ld.script to link yaboot
* Fri Apr  7 2006 olh@suse.de
- add an conf= bootoption to yaboot to specify a path to a configfile
* Fri Apr  7 2006 olh@suse.de
- fix typo in last lilo-chrp.lib  change
* Wed Apr  5 2006 olh@suse.de
- use one global default_device in yaboot
* Wed Apr  5 2006 olh@suse.de
- fix potential NULL pointer deref in set_def_device in yaboot
* Wed Apr  5 2006 olh@suse.de
- add new imagepath_to_path_description() to yaboot,
  will replace parse_file_to_load_path()
* Wed Apr  5 2006 olh@suse.de
- move the cfg_parse call out of load_config_file in yaboot
* Wed Apr  5 2006 olh@suse.de
- rename struct boot_fspec_t to path_description in yaboot
* Wed Apr  5 2006 olh@suse.de
- improve read error message in print_message_file in yaboot
* Wed Apr  5 2006 olh@suse.de
- fix potential memleak in print_message_file in yaboot
* Wed Apr  5 2006 olh@suse.de
- move processing of globals in yaboot.conf to separate function
* Wed Apr  5 2006 jplack@suse.de
- add a work around for broken EVMS configuration for SLES10 GA
* Mon Apr  3 2006 jplack@suse.de
  New version to 10.1.6 fixes:
- handle disk full error more gracefully
- xfs is now an accepted boot fs (#160895)
- extended partitions can be read be yaboot (#160897)
- fix for: /proc unmounted, then used
- lots of yaboot fixes by olh
* Wed Mar 29 2006 olh@suse.de
- dont print filename when yaboot.conf parsing fails
* Tue Mar 28 2006 olh@suse.de
- make yaboot output more OF compatible, all hex, no leading 0x
* Mon Mar 27 2006 olh@suse.de
- use malloc buffer for /chosen/bootpath in yaboot
* Mon Mar 27 2006 olh@suse.de
- update make tags to handle quilt meta data
* Mon Mar 27 2006 jplack@suse.de
- fixed #159333, FAT size calculation fails for large boot partitions
- give better/avoid/supress irritating error messages (#160078)
- moved yaboot read ability detection into function 'can_yaboot_read' to avoid code duplication
- complete code review/rework for inner config file translation
- clone= feature now really works
- FAT boot decision making code is now transparent
- partition= line creation fixed, code is transparent now (#158185)
- fixed typo in #148612
- bump version to 10.1.5
* Wed Mar 22 2006 olh@suse.de
- update libext2fs.a in yaboot to fix out-of-bounds access in
  ext2fs_namei_follow
* Wed Mar 22 2006 olh@suse.de
- improve debug output in ext2 linux_read_blk in yaboot
* Wed Mar 22 2006 olh@suse.de
- use our own yaboot.tar.bz2 from svn
* Sun Mar 19 2006 olh@suse.de
- fix reading from xfs in yaboot
* Sat Mar 18 2006 olh@suse.de
- add support for msdos extended partitions to yaboot
* Sat Mar 18 2006 olh@suse.de
- add helper function to check for usable msdos partition in yaboot
* Sat Mar 18 2006 olh@suse.de
- add helper function to check for msdos partition magic in yaboot
* Sat Mar 18 2006 olh@suse.de
- pass u64 to seek in prom_readblocks in yaboot
* Sat Mar 18 2006 olh@suse.de
- use u32 for msdos partition table start/size in yaboot
* Sat Mar 18 2006 olh@suse.de
- use u64 for prom_seek in yaboot, remove prom_lseek
* Mon Mar 13 2006 olh@suse.de
- the claim_base for kernel and initrd in yaboot was recently
  adjusted to start looking for memory at lower addresses
  This fails randomly on 32bit RS/6000. adjust claim_base to 32mb
* Tue Mar  7 2006 olh@suse.de
- remove unused blocksize argument in partition code in yaboot
* Tue Mar  7 2006 olh@suse.de
- remove unused device name argument in partition code in yaboot
* Tue Mar  7 2006 olh@suse.de
- add malloc checks in yaboot partition code
* Tue Mar  7 2006 olh@suse.de
- correct cacheflush loop to actually do something in bootheader
  add same cacheflush to yaboot
* Sun Mar  5 2006 olh@suse.de
- remove unused and misleading partition checks from yaboot
* Sun Mar  5 2006 olh@suse.de
- remove unused partition name/type members from yaboot
* Sun Mar  5 2006 olh@suse.de
- remove unused get_part_type from yaboot
* Sat Mar  4 2006 olh@suse.de
- force 16byte alignment of stackpointer in yaboot and bootheader
  depending on the location in filesystem where yaboot is compiled,
  it may be unaligned on pmac
* Sat Mar  4 2006 olh@suse.de
- remove asm code to clear bss in yaboot, its done by yaboot_start
* Wed Mar  1 2006 olh@suse.de
- correct usage of mkzimage for iseries
* Thu Feb 23 2006 jplack@suse.de
- implemented 'waiting for udev after execution of parted' function (#152028)
- enable use of boot partitions greater than 32MB
- bump version to 10.1.1
* Sat Feb  4 2006 olh@suse.de
- require powerpc-utils
* Mon Jan 30 2006 olh@suse.de
- start looking for initrd memory at lower addresses, but after
  the kernels final location
* Mon Jan 30 2006 olh@suse.de
- try harder when looking for memory for initrd in yaboot (#143795)
* Mon Jan 30 2006 olh@suse.de
- make the stackpointer value more obvious in yaboot
* Mon Jan 30 2006 olh@suse.de
- load the kernel to the lowest availabe address in yaboot
  assume the executable to load is relocateable
* Mon Jan 30 2006 olh@suse.de
- look only at the first ELF PT_LOAD section in yaboot
* Mon Jan 30 2006 olh@suse.de
- do not assume PT_LOAD is the first ELF phdr in bootheader
* Mon Jan 30 2006 olh@suse.de
- use built-in pwd -P rather than /bin/pwd (#145965)
* Wed Jan 25 2006 olh@suse.de
- link the zImage for chrp at 64k instead of 4MB (#145152)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 jplack@suse.de
- disabling firmware check for now (#144953)
* Wed Jan 25 2006 jplack@suse.de
- do extend prep partitions if neccessary (#141320)
- fix boot-device quoting
* Mon Jan 16 2006 jplack@suse.de
- handle new sysfs layout starting with kernel 2.6.15
- merge fixes from SLES9 SP3
- bump version
* Mon Jan  9 2006 olh@suse.de
- recognize the maple board in mkzimage, it has no machine: line
* Wed Jan  4 2006 olh@suse.de
- provide a md5sum function in yaboot
* Wed Jan  4 2006 olh@suse.de
- use md5_init() where possible in yaboot md5.c
* Wed Jan  4 2006 olh@suse.de
- compile and run a md5test app during yaboot compilation
* Tue Jan  3 2006 olh@suse.de
- remove the yaboot.fat file, it is equal to yaboot.chrp
* Tue Jan  3 2006 olh@suse.de
- yaboot must always load the initrd if it is specified
  basing this decision on the the ELF entry point breaks when the
  entry point differs from yaboots assumptions
* Tue Dec 13 2005 olh@suse.de
- adapt lilo script to new bash to prevent syntax errors (#138447)
* Mon Dec 12 2005 olh@suse.de
- fix NULL pointer confusion in yaboot prom.c
* Mon Dec 12 2005 olh@suse.de
- add vendor to zImage banner
* Sat Dec 10 2005 olh@suse.de
- set claim_base to 5MB for OldWorld in bootheader
* Sat Dec 10 2005 olh@suse.de
- do bytecopy in memcpy if src unaligned
* Sat Dec 10 2005 olh@suse.de
- claim memory in the /memory and mmu node on old Macs in bootheader
* Sat Dec 10 2005 olh@suse.de
- add call_prom_ret to bootheader
* Fri Dec  9 2005 olh@suse.de
- do not ignore the return value from prom in call_prom in yaboot
* Fri Dec  9 2005 olh@suse.de
- do not ignore the return value from prom in call_prom in bootheader
* Fri Dec  9 2005 olh@suse.de
- prom_entry in bootheader returns int, not void
* Fri Dec  9 2005 olh@suse.de
- better memcpy in bootheader to deal with unaligned src/dest
* Thu Dec  8 2005 olh@suse.de
- print kernel entry address unconditionally in bootheader
* Sat Dec  3 2005 olh@suse.de
- do not strip binaries in during rpm build (134860)
* Sat Dec  3 2005 olh@suse.de
- remove leading zeros from partition number in of_open in yaboot.
  OpenFirmware handles it as whole disk (136537 - LTC20058)
* Tue Nov 22 2005 olh@suse.de
- remove -s option from strip in make_zimage* scripts, to remove debug
* Wed Nov  9 2005 olh@suse.de
- remove need for extra System.map in iseries-addRamDisk
* Wed Nov  9 2005 olh@suse.de
- remove initalizers for locals in iseries-addRamDisk
* Sat Oct 29 2005 olh@suse.de
- update memcpy in bootheader to deal with unaligned src/dest
* Sat Oct 29 2005 olh@suse.de
- reduce claim_base to 32MB in bootheader, oldworld cant handle 64MB
* Sat Oct  1 2005 olh@suse.de
- remove all unneeded stuff from ld.script in bootheader
* Sat Oct  1 2005 olh@suse.de
- make the bootheader relocateable
* Sat Oct  1 2005 olh@suse.de
- use memset to clear the bss on chrp in bootheader
* Sat Oct  1 2005 olh@suse.de
- remove PROVIDE from bootheader linker script, adapt prep
* Sat Oct  1 2005 olh@suse.de
- remove mkzimage tmp dir after image creation for iseries and prep
* Sat Oct  1 2005 olh@suse.de
- append a 0x0 to the utsstring in bootheader
* Mon Sep 12 2005 jplack@suse.de
- needed option get-arch for ppc bootloader config to work right
* Thu Sep  8 2005 olh@suse.de
- add console= hint to prep part in bootheader
* Thu Sep  8 2005 olh@suse.de
- remove _FORTIFY_SOURCE from RPM_OPT_FLAGS because the binaries
  have to run on SLES9 as well.
* Mon Sep  5 2005 olh@suse.de
- require gawk sed coreutils instead of absolute path names
* Thu Sep  1 2005 olh@suse.de
- try to claim different memory regions if the (currently hardcoded)
  value is busy because the firmware uses this area. (#88481 - LTC16331)
* Wed Aug 24 2005 olh@suse.de
- correct path to mkzimage for PReP
* Mon Aug 22 2005 olh@suse.de
- set claim_base in bootheader to 64MB
  maple firmware returns memory which is in use for message passing
* Mon Aug 22 2005 olh@suse.de
- allow make DEBUG=1 in bootheader
* Mon Aug 22 2005 olh@suse.de
- correct tmpdir name in make_zimage_chrp.sh
* Sun Aug 21 2005 olh@suse.de
- handle 'partition=' without 'device=' in yaboot.conf
* Fri Aug 19 2005 olh@suse.de
- add the same cpu table to yaboot
* Fri Aug 19 2005 olh@suse.de
- not all 64bit hosts have the 64-bit property in the boot cpu node
  add a cputable to bootheader to match cpus to 32/64 bit
* Tue Aug 16 2005 olh@suse.de
- fix logic error in yaboot when checking if config file was loaded
* Tue Aug 16 2005 olh@suse.de
- ignore empty input line if yaboot could not load its config file
* Tue Aug 16 2005 olh@suse.de
- allocate tftp download area dynamically in yaboot,
  12MB starting at 42MB
* Tue Aug 16 2005 olh@suse.de
- add optional debug to prom_claim calls in yaboot
* Tue Aug 16 2005 olh@suse.de
- compile yaboot with -g to simplify debugging, do not strip it
* Tue Aug 16 2005 olh@suse.de
- add man page for mkzimage and mkzimage_cmdline
* Tue Aug 16 2005 olh@suse.de
- package /bin/mkzimage_cmdline
* Tue Aug 16 2005 jplack@suse.de
- interpret /etc/SuSE-release if available to construct an
  appropriate bootinfo object (#104622)
* Mon Aug 15 2005 olh@suse.de
- remove unused options passed to prom_init in yaboot
* Mon Aug 15 2005 olh@suse.de
- add a hint for PReP with openfirmware about console usage
  in bootheader
* Mon Aug 15 2005 jplack@suse.de
- in case of dynamic device nodes those might disappear temporarily
  even after partition resize.  So wait a little (#104621)
* Mon Aug 15 2005 olh@suse.de
- move init-message/message output after vertical indention
* Sun Aug 14 2005 olh@suse.de
- claim the mem range of the yaboot executable.
  some firmware versions dont do it
* Sun Aug 14 2005 olh@suse.de
- print stack pointer and yaboot location in yaboot
* Sun Aug 14 2005 olh@suse.de
- print stack pointer in bootheader, print hint about cmdline edit
* Sat Aug 13 2005 olh@suse.de
- remove unused firmware code for release method
* Sat Aug 13 2005 olh@suse.de
- remove unused code for pause-after/pause-message options
* Sat Aug 13 2005 olh@suse.de
- do not print garbage in reiserfs_read_super debug output
* Sat Aug 13 2005 olh@suse.de
- always free config file buffer after parsing
* Fri Aug 12 2005 olh@suse.de
- change all #if DEBUG into #ifdef DEBUG
  adjust Makefile to pass -O1 -g if DEBUG=2
* Thu Aug 11 2005 olh@suse.de
- print newline after clear screen to get indention of next line
* Thu Aug 11 2005 olh@suse.de
- append comma to enet:bootp bootpath
* Thu Aug 11 2005 olh@suse.de
- handle missing colon in /chosen/bootpath in yaboot
* Thu Aug 11 2005 olh@suse.de
- look only for /chosen/bootpath if global bootdevice is empty
* Mon Aug  8 2005 olh@suse.de
- print stack and prom pointer, and yaboot memory range on startup
* Mon Aug  8 2005 jplack@suse.de
- fixed trapping, reordered script to fix error handling, cleaned
  unused stuff (#102519)
* Mon Aug  8 2005 olh@suse.de
- close yaboot config file after reading to release tftp area
* Sun Aug  7 2005 olh@suse.de
- correct dereference of NULL in RAID partition patch
* Sun Aug  7 2005 olh@suse.de
- remove alot of code which were unused after the last change
* Sun Aug  7 2005 olh@suse.de
- use the new parse_device_path api in yaboot, will fix netboot
  on rs6k and ramdisk loading from system folder on hfs
  obsoletes yaboot.fat, it looks now for yaboot.cnf, yaboot.conf
  or /etc/yaboot.conf
* Sun Aug  7 2005 olh@suse.de
- split of_net_download of of_net_open in yaboot to reuse download
  buffer if yaboot.conf file was not found.
* Sun Aug  7 2005 olh@suse.de
- do not vertical indent in yaboot if DEBUG is set
* Sun Aug  7 2005 olh@suse.de
- fill the malloc area with 'A' in yaboot
* Sun Aug  7 2005 olh@suse.de
- build yaboot with -O1 -g if DEBUG is set
* Sun Aug  7 2005 olh@suse.de
- clear the whole struct in open_file in yaboot, not just a pointer
* Sun Aug  7 2005 olh@suse.de
- provide Changelog.SuSE in yaboot.patch
* Sun Aug  7 2005 olh@suse.de
- move fserrorno from fs.h to fs.c in yaboot
* Sat Aug  6 2005 olh@suse.de
- fix NULL pointer confusion in cfg_get_strg/flag calls in yaboot
* Sat Aug  6 2005 olh@suse.de
- add README.searchpath to yaboot
* Thu Aug  4 2005 jplack@suse.de
- use FAT boot for xfs file systems as yaboot xfs driver seems to
  have some problems with it natively (#100704)
* Thu Aug  4 2005 jplack@suse.de
- merged Makefile changes from SLES9 branch
* Thu Aug  4 2005 jplack@suse.de
- merged fixes from SLES9 branch
- added code to handle parted´s incompatible switch to SI units
  in version 1.6.23 or later (#100411)
- split out iseries and chrp code for easier maintainance
- alternative firmware level calculation for Power5 or later
- fix procfs detection for iSeries
- fix boot problem while using force_fat option
- fix a couple of typos/syntax error
- better error messages for the firmware detection framework
- added framework to detect and workaround or bail out for fatal
  firmware bugs
- fc_transport uses decimals not hex digits, support for more
  than nine luns or scsi channels or hosts for FC disks (#87235 -
  LTC16290)
- Make sure that /proc and /sys is mounted while running lilo or
  show_of_path.sh, not failing in rescue system (#85852).
* Wed Aug  3 2005 olh@suse.de
- use c99 initializers for struct fs_t usage in yaboot
* Wed Aug  3 2005 olh@suse.de
- indent the yaboot text output by one tab
* Sun Jul 24 2005 olh@suse.de
- handle block pathnames without partition part in parse_device_path
* Sun Jul 24 2005 olh@suse.de
- add new parse_device_path function to yaboot
  add new util/split_of_path to test the new function
* Sun Jul 24 2005 olh@suse.de
- reset LANG in yaboot Makefile, build hosttools with -O1 -g
* Sun Jul 24 2005 olh@suse.de
- print /chosen/boot-device in yaboot welcome message (for debugging)
* Sun Jul 24 2005 olh@suse.de
- remove birec code from yaboot, was only needed for sysmap
  xmon uses kallsyms now
* Sun Jul 24 2005 olh@suse.de
- remove sysmap code from yaboot
* Sun Jul 24 2005 olh@suse.de
- change return type of prom_get_devtype to enum in yaboot
* Sun Jul 24 2005 olh@suse.de
- handle RAID partitions on x86 partition tables in yaboot
  (Patch from Dustin Kirkland)
* Sun Jul 24 2005 olh@suse.de
- add support for amiga partition tables to yaboot  (Sven Luther)
* Sun Jul 24 2005 olh@suse.de
- rename log2 in yaboot reiserfs code
* Sun Jul 24 2005 olh@suse.de
- disable dead code in yaboot, remove unneeded global initializers
* Sat Jul 23 2005 olh@suse.de
- add support for ieee1394 sbp2 devices to show_of_path.sh
* Thu Jul 21 2005 olh@suse.de
- fix off by one in chrp setup call in bootheader
* Tue Jul 19 2005 olh@suse.de
- allocate a buffer for extracted vmlinux on prep machines with
  OpenFirmware. Overwrite firmware memory later.
* Tue Jul 19 2005 olh@suse.de
- remove global variable in prep bootheader
* Tue Jul 19 2005 olh@suse.de
- some prep machines have openfirmware, but reading from keyboard
  returns no data. read directly from the hardware in this case
* Tue Jul 19 2005 olh@suse.de
- read from stdin, not stdout in prep bootheader
* Tue Jul 19 2005 olh@suse.de
- use new get_cmdline also on prep in bootheader
* Tue Jul 19 2005 olh@suse.de
- add the ability to edit the built-in cmdline in bootheader
* Tue Jul 19 2005 olh@suse.de
- print openfirmware entry point on prep in bootheader
* Tue Jul 19 2005 olh@suse.de
- getprop returns an ihandle, update prototypes in bootheader
* Mon Jul 18 2005 olh@suse.de
- add mdleay function to chrp/prep in bootheader
* Sun Jul 17 2005 olh@suse.de
- add read function to chrp/prep in bootheader
* Sun Jul 17 2005 olh@suse.de
- add of1275_milliseconds function to bootheader
* Sat Jul 16 2005 olh@suse.de
- remove all '\r' in bootheader
* Sat Jul 16 2005 olh@suse.de
- convert all '\n' into '\n\r' in bootheader printf
* Mon Jul 11 2005 olh@suse.de
- add a missing newline to prep bootheader
* Thu Jul  7 2005 olh@suse.de
- fix logic in image[32bit]/image[64bit] handling for yaboot.conf
* Mon Jul  4 2005 olh@suse.de
- build prep support from source in bootheader
* Mon Jul  4 2005 olh@suse.de
- change prototype of gunzip in bootheader, return the length
* Mon Jun 27 2005 olh@suse.de
- split builtin_cmdline in bootheader
* Sun Jun 26 2005 olh@suse.de
- move write function to chrp/main in bootheader
* Sun Jun 26 2005 olh@suse.de
- split gunzip function in bootheader
* Sun Jun 26 2005 olh@suse.de
- add an abort function to bootheader
* Sun Jun 26 2005 olh@suse.de
- add a stdlib.h, move exit function prototype
* Sun Jun 26 2005 olh@suse.de
- add an exit function to bootheader
* Fri Jun 24 2005 olh@suse.de
- add of1275_interpret function to bootheader
* Wed Jun 22 2005 olh@suse.de
- improve mkzimage --help output
* Mon Jun 20 2005 olh@suse.de
- mark scripts and textfiles as config to keep local modifications
* Mon Jun 20 2005 olh@suse.de
- fix /bin dir creation in bootheader/utils/Makefile
* Sun Jun 19 2005 olh@suse.de
- check for iso6429-1983-colors property before using ANSI colors
  in yaboot
* Sun Jun 19 2005 olh@suse.de
- add image[32bit]/image[64bit] handling for yaboot.conf
* Sat Jun 18 2005 olh@suse.de
- find "cpu" nodes instead of /chosen/cpu to set cpu type
* Sat Jun 18 2005 olh@suse.de
- use strip -o in make_zimage*sh for files with u-w permission
* Thu Jun 16 2005 olh@suse.de
- use own ppc_asm.h instead of gcc provided one, it defines r1 etc.
* Thu Jun 16 2005 olh@suse.de
- claim the mem range of the zimage executable.
  some firmware versions dont do it, zlib may overwrite the memory
* Thu Jun 16 2005 olh@suse.de
- print the whole executable mem range in zimage startup message
* Thu Jun 16 2005 olh@suse.de
- stdio.h in bootheader needs stdarg.h for valist
* Wed Jun 15 2005 olh@suse.de
- fix pattern for IDE drive recognition
* Tue Jun 14 2005 olh@suse.de
- tweak kernel_entry_t prototype in bootheader
* Tue Jun 14 2005 olh@suse.de
- replace calls into prom.c with new OF functions in bootheader
* Tue Jun 14 2005 olh@suse.de
- correct argument order for map call in bootheader
* Tue Jun 14 2005 olh@suse.de
- string.h needs stddef.h in bootheader
* Tue Jun 14 2005 olh@suse.de
- declare the new OF functions as extern in prom.h in bootheader
* Tue Jun 14 2005 olh@suse.de
- add a bunch of OF functions into chrp/prom.a in bootheader
* Tue Jun 14 2005 olh@suse.de
- rename chrp/prom.a to chrp/chrp.a in bootheader
* Tue Jun 14 2005 olh@suse.de
- run chrp/*.c through Lindent
* Tue Jun 14 2005 olh@suse.de
- define and use ihandle and phandle types in bootheader
* Fri Jun 10 2005 olh@suse.de
- try claim from 0x0, up to 128MB in bootheader
* Fri Jun 10 2005 olh@suse.de
- reduce output in bootheader
* Fri Jun 10 2005 olh@suse.de
- reduce the zlib workspace from 128k to 46912 in bootheader
* Fri Jun 10 2005 olh@suse.de
- use abort() also in gunzip in bootheader
* Fri Jun 10 2005 olh@suse.de
- zeropad the ELF debug output in bootheader
* Wed Jun  8 2005 olh@suse.de
- dont use ANSI colors on pmac telnet console
* Wed Jun  8 2005 olh@suse.de
- use p->p_vaddr as loadaddr in yaboot, not the ELF entry point
  reenable COFF function descriptor
* Wed Jun  8 2005 olh@suse.de
- update yaboot makerules to avoid relinking during each make run
* Tue Jun  7 2005 olh@suse.de
- yaboot does not handle ->e_entry points at unaligned offsets
  disable for COFF function descriptor for the time being
* Tue Jun  7 2005 olh@suse.de
- add %%ll support to vsprintf in bootheader
* Tue Jun  7 2005 olh@suse.de
- change the exit() calls in chrp/main.c into abort(string) calls
* Tue Jun  7 2005 olh@suse.de
- remove the dead getprop(memory) and instance_to_package call
  JS20 has a /chosen/memory property, but its content is 0
* Tue Jun  7 2005 olh@suse.de
- fix function declaration warning for exit()
* Tue Jun  7 2005 olh@suse.de
- split common/stdio.c off chrp/prom.c in bootheader
* Tue Jun  7 2005 olh@suse.de
- remove global initializers from bootheader
* Sat Jun  4 2005 olh@suse.de
- move some bootheader .o files into prom.a and common.a
* Thu Jun  2 2005 olh@suse.de
- map the claimed memory only if relocation is enabled
* Thu Jun  2 2005 olh@suse.de
- update lilo to call mkzimage instead of hardcoded make_zimage_prep.sh
  and make_zimage_iseries.sh
* Thu Jun  2 2005 olh@suse.de
- remove pmac binaries from repository, remove leftover iseries dir
* Thu Jun  2 2005 olh@suse.de
- map the claimed memory in bootheader, older firmware on pmac
  doesnt do it. power4 firmware gets a stack underflow in the map
  call, so do it only for 32bit
* Wed Jun  1 2005 jplack@suse.de
- be more precise on path globbing, use extglob (#73638)
- support new 2.6.10+ scsi sysfs layout (#73638)
- quote root parameter if neccessary (#80223, #85605)
- prepare boot partition clone feature
* Tue May 31 2005 olh@suse.de
- only call map method on 32-bit machines in bootheader
* Tue May 31 2005 olh@suse.de
- add a phandle to get the /memory/available property
* Tue May 31 2005 olh@suse.de
- addnote relies on a fixed ELF header layout, declare .uts_string
  in ld.script to satisfy these expectations
* Tue May 31 2005 olh@suse.de
- make _start look like a function descriptor for COFF
* Tue May 31 2005 olh@suse.de
- use the mknote util in mkzimage --board pmac
* Tue May 31 2005 olh@suse.de
- add mknote to bootheader
* Mon May 30 2005 olh@suse.de
- move mkzimage_cmdline and iseriesAddRamdisk to bootheader
* Mon May 30 2005 olh@suse.de
- rename make_zimage_chrp64.sh to make_zimage_chrp.sh
  recognize also 32bit chrp
* Mon May 30 2005 olh@suse.de
- add hack-coff binary from 2.6.12-rc5
* Mon May 30 2005 olh@suse.de
- update make_zimage_pmac*sh to match make_zimage_chrp64.sh
  link coff binary at 16MB
* Mon May 30 2005 olh@suse.de
- use the new ld.script for chrp64,
  remove the .kernel:cmdline section
* Mon May 30 2005 olh@suse.de
- add add arch/ppc/boot/ld.script from 2.6.12-rc5 to bootheader
* Mon May 30 2005 olh@suse.de
- add option --objdir to mkzimage with /lib/lilo as default
* Mon May 30 2005 olh@suse.de
- move all make_zimage_*.sh scripts to /lib/lilo/scripts
* Mon May 30 2005 olh@suse.de
- add check_elf32 function to bootheader
* Mon May 30 2005 olh@suse.de
- look at the ELF header to determine the required claim size,
  do not define the vmlinux file and memsize via ld options anymore
- pass Z_FULL_FLUSH instead of Z_FINISH to zlibc to extract only
  a part of the vmlinux.gz
* Mon May 30 2005 olh@suse.de
- move do_gunzip before use
* Mon May 30 2005 olh@suse.de
- remove unneeded zalloc function in bootheader
* Mon May 30 2005 olh@suse.de
- use zlib_inflate from 2.6.12-rc5
* Mon May 30 2005 olh@suse.de
- split check_elf64 function in bootheader
* Mon May 30 2005 olh@suse.de
- split gunzip function in bootheader
* Mon May 30 2005 olh@suse.de
- add mmu ihandle and map call-method to map the claimed memory
* Mon May 30 2005 olh@suse.de
- add instance-to-package call to bootheader to get the cpu type
* Mon May 30 2005 olh@suse.de
- build bootheader with LANG=C
* Mon May 30 2005 olh@suse.de
- build bootheader with -Os -msoft-float
* Mon May 30 2005 olh@suse.de
- remove --save-temps from bootheader CFLAGS
* Mon May 30 2005 olh@suse.de
- use the gcc provided ppc-asm.h instead of the selfprovided ppc_asm.h
* Sun May 22 2005 olh@suse.de
- update prep binary objects in bootheader to 2.6.12-rc4,
  including the mkzimage_cmdline part
* Sun May 22 2005 olh@suse.de
- readd div64 to bootheader package, required for negative numbers
  in vsprintf
* Thu May 19 2005 olh@suse.de
- fix some pointer 0/NULL confusion in yaboot
* Thu May 19 2005 olh@suse.de
- add makefile dependencies to yaboot
* Tue May 10 2005 jplack@suse.de
- fix: lilo produces append= line without root= (#81278)
* Sun May  8 2005 olh@suse.de
- move declarations in bootheader package to header files,
  remove unused header files
* Sun May  8 2005 olh@suse.de
- remove unneeded div64.o from bootheader package
* Tue May  3 2005 olh@suse.de
- be less verbose in make_zimage*.sh scripts
* Mon May  2 2005 olh@suse.de
- fix #define for yaboot.cnf
* Thu Apr 28 2005 jplack@suse.de
- check for yaboot.conf on bad volume (#58521 - LTC10252)
* Thu Apr 28 2005 jplack@suse.de
- avoid empty partition line in yaboot.conf
  fixes #65759 - lilo produces unparsable yaboot.conf for FAT case
- moved the problem detection for unknown OF path earlier in the
  process flow to have less irritation in case of unknown
  hardware (#48446)
* Thu Apr 28 2005 olh@suse.de
- add /bin/mkzimage as wrapper around the make_zimage_${board}.sh
  scripts below /lib/lilo (#50570)
* Thu Apr 28 2005 olh@suse.de
- add option --no-addnote to make_zimage_chrp64.sh for pmac64
* Wed Apr 27 2005 olh@suse.de
- pass -m32 to gcc, ld and as to fix yaboot built on native ppc64
  build addnote with hostcc
* Wed Apr 27 2005 olh@suse.de
- update mkzimage_cmdline, use mmap, put it into /bin
* Wed Apr 27 2005 olh@suse.de
- addnote.c: Patch from Paul Mackerras to add second .note
  required by more recent pSeries hardware. (#67026 - LTC14213)
* Wed Apr 27 2005 olh@suse.de
- update yaboot to 1.3.13
* Tue Apr 26 2005 olh@suse.de
- build the binaries in /lib/lilo/chrp/ from source
  instead of keeping binaries in the source repository
  move make_zimage_chrp64.sh from /lib/lilo/chrp/chrp64 one dir up,
  keep compat symlink (part of #67026 - LTC14213)
* Mon Mar 21 2005 olh@suse.de
- update chrp/chrp64/addRamdisk.sh to use make_zimage_chrp64.sh
* Fri Mar 18 2005 olh@suse.de
- update chrp64 zImage bootheader for 2.6.7 kernels
* Thu Mar 17 2005 olh@suse.de
- handle more than one SATA drive in G5 (#73635)
* Wed Feb 23 2005 schwab@suse.de
- Bump version.
* Wed Jan 12 2005 schwab@suse.de
- show_of_path.sh: handle new targetN subdir in SCSI hosts.
* Thu Dec 16 2004 jplack@suse.de
- added work arounds for some problems and bugs of parted (#49317)
  prepend root= option to append line (#48419)
* Fri Dec 10 2004 jplack@suse.de
- added support for QLogic FC adapters on JS20, cleanup so that
  all FC adapters using fc_transport class should work (# 45565 -
  LTC11213)
* Thu Nov  4 2004 jplack@suse.de
- use parted's fs resize command to resize partition inplace,
  resolves blocker #47956, add more verbosity to parted related
  error messages
* Thu Nov  4 2004 jplack@suse.de
- added partition number to yaboot.conf to make disk migration
  work in all cases
* Fri Oct 29 2004 jplack@suse.de
- added fix for #47765
* Wed Oct 20 2004 jplack@suse.de
- added a tested fix for #45565 at least for emulex FC cards
* Mon Oct 18 2004 jplack@suse.de
- added some more fixes for #45565
* Thu Oct  7 2004 jplack@suse.de
- remove OF path to partition if same as for the config file itself
* Thu Oct  7 2004 jplack@suse.de
- check for all relevant files beeing on primary partitions,
  firmware has problems else ...
- added 'force_fat' option for some hopeless configurations
* Thu Oct  7 2004 jplack@suse.de
- delete ambiguous PReP boot partitions (#42903)
* Thu Jul  8 2004 jplack@suse.de
- fixed problem with leading zeros (#42854)
* Tue Jun 29 2004 jplack@suse.de
- workaround an OF bug documented in #42517
* Wed Jun 23 2004 jplack@suse.de
- fixed blocker bug #41772 - LTC9179-SLES9: Installation of RAID
  1 failed
* Fri Jun 18 2004 jplack@suse.de
- fixed critical bug #42207 - lilo does not handle /dev/root in
  /proc/mounts
* Thu Jun 17 2004 jplack@suse.de
- use TMPDIR if set
* Thu Jun 17 2004 jplack@suse.de
- fixed #42148, lilo cannot handle more than 10 partitions
* Wed Jun 16 2004 olh@suse.de
- remove hardcoded /boot/System.map path on iseries (#42000)
  use prep binary boot header from current kernel-source package
  do not call /sbin/activate on prep anymore, its gone
  disable debug output in makezimage.sh scripts
* Thu Jun  3 2004 jplack@suse.de
- entries without initrd have been errornously ignored
* Tue Jun  1 2004 jplack@suse.de
- fixed #41333, do of screen init
* Fri May 28 2004 jplack@suse.de
- fixed #41331, parser error
* Wed May 26 2004 jplack@suse.de
- prevent parted from going interactive
* Tue May 25 2004 jplack@suse.de
- ugly typo fixed / lilo stopped execution
* Mon May 24 2004 jplack@suse.de
- remove moint point from OF path in show_of_path.sh (#40999)
* Mon May 24 2004 jplack@suse.de
- fix yet another parser bug
* Wed May 19 2004 jplack@suse.de
- merged lilo&bootheader tar balls, implemented smart PReP
  partition handling including expansion/shrinking on the fly.
* Thu May 13 2004 jplack@suse.de
- follow symlinks to get file size, umount boot on clean up, clear
  LANG and LC_CTYPE on startup
* Wed May 12 2004 jplack@suse.de
- better error handling, work around YaST bugs (e.g. boot="" bug),
  some smaller glitches
* Mon May 10 2004 jplack@suse.de
- fixed typos for PowerMac G5s
* Fri May  7 2004 jplack@suse.de
- create bootinfo object, more error checking, type conversion for
  PReP Boot partition
* Fri May  7 2004 jplack@suse.de
- vscsi detection, #40002
* Wed May  5 2004 jplack@suse.de
- fixed guessing of boot partition, various cleanups, fixed custom
  error handling.
* Mon May  3 2004 jplack@suse.de
- fixed various pmac bugs/cleanup of pmac handling
* Mon May  3 2004 jplack@suse.de
- fixed typo in lilo triggering bash bug, implemented booting from
  non standard file systems though a FAT boot file system (#34556)
  and others.
* Mon Apr 26 2004 jplack@suse.de
- fixed show_of_path.sh: support for IPR controller and such #39033
  mounts /sys if needed, #39380
* Fri Apr  2 2004 jplack@suse.de
- fixed show_of_path.sh: scsi_id and scsi_lun are given in hex
  instead of decimal
* Wed Mar 31 2004 jplack@suse.de
- set OF variable boot-device to point to your boot device
* Tue Mar 30 2004 jplack@suse.de
- fixes #37294: fixed command line handling, and #37291
* Fri Mar 26 2004 jplack@suse.de
- workaround for possible bug in yaboot, avoid initrd option by
  using addRamdisk.sh, use fullpath for fdisk (path not set with
  init=/bin/bash)
* Wed Mar 24 2004 jplack@suse.de
- fixed type, bug with device detection, lots of clean ups
* Tue Mar 23 2004 jplack@suse.de
- update to bootheader-0.0.5, mac fix
* Tue Mar 23 2004 jplack@suse.de
- update to version lilo-0.0.8, support of multiple boot= lines for
  iSeries, more clean ups
* Tue Mar  2 2004 olh@suse.de
- make zImage helpers exectable, copy dummy .o file on chrp
* Sun Feb 22 2004 olh@suse.de
- add make_zimage*.sh for pseries and iseries, fix prep script
* Mon Feb 16 2004 olh@suse.de
- run /sbin/activate unconditionally
  handle devspec sysfs property for sata
* Thu Feb 12 2004 olh@suse.de
- add make_zimage*.sh scripts for pmac coff and new pmac, prep
* Tue Feb 10 2004 olh@suse.de
- add /lib/lilo/iseries/iseries-addRamDisk,
  from kernel-iseries64-tools
* Sat Jan 31 2004 olh@suse.de
- update to yaboot-1.3.11
  update show_of_path.sh to use sysfs
  update lilo to use MacRISC* instead of compatible_machines.txt
  move files from /boot to /lib/lilo/
  preserve lilo.conf in postinstall
* Tue Dec  2 2003 olh@suse.de
- move /boot/lib/chrp/* to /lib/lilo
* Wed Nov 13 2002 olh@suse.de
- requires: binutils for linking the kernel on pseries
* Tue Nov 12 2002 olh@suse.de
- support initrd on pseries
* Fri Nov  8 2002 olh@suse.de
- add yaboot-hole_data-journal.diff
  fix loading of files with holes on reiserfs
* Thu Oct 17 2002 olh@suse.de
- activate a kernel slot with the 'activate' config option
  zero cmdline in kernel slot
* Tue Aug 27 2002 olh@suse.de
- remove some unwanted debug output on iSeries
* Tue Aug 27 2002 olh@suse.de
- fix append= handling from last change
* Sun Aug 25 2002 olh@suse.de
- better handling of iSeries specific options
  write kernel to kernel slot or stream file or prep boot partition
* Sun Aug 11 2002 olh@suse.de
- check for empty image= line on newworld, avoids warning
* Sat Aug  3 2002 olh@suse.de
- load system.map on new pmacs, for debugger
  unset boot-file on new pmacs, breaks yaboot
* Wed Jul  3 2002 olh@suse.de
- use MacRISC as compatible string on pmac
* Sat Jun 29 2002 olh@suse.de
- add yaboot-symlink-fix.diff (#16742), allow symlinks on reiserfs
* Mon Jan 14 2002 olh@suse.de
- remove exit 0, no quoting for lilo.conf variables
* Fri Jan 11 2002 olh@suse.de
- build a boot image with initrd=  on iSeries, when specified
* Thu Jan 10 2002 olh@suse.de
- do not write to slot C on iSeries
* Wed Jan  9 2002 olh@suse.de
- do not write to slot A on iSeries
* Wed Jan  9 2002 olh@suse.de
- add root= option on iseries
* Tue Jan  8 2002 olh@suse.de
- do not honor the boot-file/bootargs content in yaboot
* Tue Jan  8 2002 olh@suse.de
- run lilo on iSeries
* Thu Dec 20 2001 olh@suse.de
- do not call rpm postinstall
* Thu Dec 13 2001 olh@suse.de
- update to yaboot 1.3.6, remove some partition type braindamage
* Tue Dec  4 2001 olh@suse.de
- add new PowerBook
* Tue Dec  4 2001 olh@suse.de
- running lilo on iSeries
* Tue Nov 13 2001 olh@suse.de
- double MAX_TOKEN size to allow large init-message
* Thu Nov  8 2001 olh@suse.de
- the last yaboot patch screwed the older changes, apply them again
* Thu Nov  8 2001 olh@suse.de
- add patch to allow loading for zImage.initrd on ppc64
* Mon Oct 15 2001 olh@suse.de
- fix yaboot.conf creation, sysmap= was wrong
* Mon Oct 15 2001 olh@suse.de
- add patch from jeffm to fix image loading on chrp+reiserfs
* Mon Oct  8 2001 olh@suse.de
- do nothing on oldworld when called with --lilo-rootdrive
  might be bad for your MacOS partition
* Wed Oct  3 2001 olh@suse.de
- use --lilo-rootdrive when df / produce bogus output
  needed for installer
* Mon Sep 24 2001 olh@suse.de
- do not exit when sysmap can not be loaded
* Sat Sep 22 2001 olh@suse.de
- fix spacebar message
* Thu Sep 20 2001 olh@suse.de
- change type of Mac OS Rom and install
* Thu Sep 20 2001 olh@suse.de
- update yaboot to 1.2.5, fixes for ppc64
* Wed Sep 19 2001 olh@suse.de
- fix sysmap for pmac
* Wed Sep 19 2001 olh@suse.de
- fix sysmap path for chrp
* Sat Sep 15 2001 olh@suse.de
- make spacebar useage more clear
* Fri Sep 14 2001 olh@suse.de
- improve handling of spacebar in os-chooser
* Wed Sep  5 2001 olh@suse.de
- fix specfile
* Wed Sep  5 2001 olh@suse.de
- update yaboot to 1.2.3, use new os-chooser version per default
* Tue Aug 14 2001 olh@suse.de
- fix filelist
* Mon Aug 13 2001 olh@suse.de
- update compatible_machines.txt comment
* Mon Aug 13 2001 olh@suse.de
- update lilo.sh, fix handling of HFSBOOTFOLDER
  use a different way to query keys in os-chooser script
  fix yaboot, netboot was broken in last update
* Wed Aug  8 2001 olh@suse.de
- update compatible_machines.txt
* Wed Aug  8 2001 olh@suse.de
- move compatible_machines.txt
  dont force copy on new Macs until yaboot is fixed
* Thu Aug  2 2001 olh@suse.de
- fix birec calculation, needs still work for HFS load ...
* Wed Aug  1 2001 olh@suse.de
- set sysmap_base to 0
* Tue Jul 31 2001 olh@suse.de
- add yaboot-fix.diff for reiserfs mount
* Tue Jul 31 2001 olh@suse.de
- update default lilo.conf
* Tue Jul 31 2001 olh@suse.de
- update to current yaboot patch for reiserfs (jeffm)
  add sysmap loading patch and update version to 1.2.2
* Mon Jul 23 2001 olh@suse.de
- fix the default= option when it is macos, use first kernel label
* Mon Jul  2 2001 olh@suse.de
- bring back some modifications
  always copy the files on the new MacRISC2 machines
* Thu Jun 28 2001 olh@suse.de
- fix yaboot.c  file_close
* Thu Jun 28 2001 olh@suse.de
- miboot can read a config file now
* Sun Jun 17 2001 olh@suse.de
- honor default= line in lilo.conf for macos booting
* Sat Jun  2 2001 olh@suse.de
- update yaboot to 1.2.1, add reiserfs patches
* Fri Mar  9 2001 olh@suse.de
- rename os-chooser to Mac OS Rom
  add some support for Mac OS X to lilo.conf
* Mon Mar  5 2001 olh@suse.de
- add PowerMac4,1 for new flower power iMacs
* Tue Feb 27 2001 olh@suse.de
- add PowerMac3,4 for new G4/466
* Tue Feb 27 2001 olh@suse.de
- enable initrd creation again, loop-6 fix most problems
* Tue Feb 27 2001 olh@suse.de
- update to 0.0.7
  update yaboot to 1.1.1, obsoletes chrp64 binary
  change /sbin/lilo to handle the new files
* Thu Feb 15 2001 olh@suse.de
- disable misleading debug printf in yaboot
* Wed Feb 14 2001 olh@suse.de
- handle first generation iMac in lilo
* Sun Feb 11 2001 olh@suse.de
- handle /dev/hde in show_of_path.sh
* Sun Feb 11 2001 olh@suse.de
- skip initrd creation with 2.4 kernel and old pmacs
  until the loop device is fixed
* Sun Feb 11 2001 olh@suse.de
- add small fixes for chrp to yaboot
* Tue Jan 30 2001 olh@suse.de
- add " screen" output to lilo itself
* Tue Jan 30 2001 olh@suse.de
- activate partitions via nvsetenv on new PowerMacs
* Tue Jan 30 2001 olh@suse.de
- avoid screen garbage on chrp serial console
* Tue Jan 30 2001 olh@suse.de
- disable " screen" output, doesnt work anyway
* Sun Dec 17 2000 olh@suse.de
- use yaboot 0.9 on pmac and chrp
* Sun Dec 17 2000 olh@suse.de
- add support for System.map loading (sysmap=)
* Fri Dec  1 2000 olh@suse.de
- remove quik, build debug binaries on CHRP
* Tue Oct 24 2000 olh@suse.de
- clear BSS on chrp, fix typo in /sbin/lilo, use always yaboot.conf
* Wed Oct 11 2000 olaf@suse.de
- update to yaboot 0.9 for chrp only, allows bootable CDs
* Mon Oct  9 2000 olh@suse.de
- add POWER3 support to install yaboot.chrp{,.64}
* Fri Sep 29 2000 olh@suse.de
- disable debug on chrp
* Wed Sep 27 2000 olh@suse.de
- exit when no boot= is specified
* Wed Sep 27 2000 olh@suse.de
- disable debug in yaboot.chrp, fix <NULL> output in defaultimage
* Thu Sep 21 2000 olh@suse.de
- fix show_of_path, lilo.sh and yaboot.c at once
* Thu Sep 21 2000 olh@suse.de
- update yaboot for chrp, update lilo to handle chrp
* Mon Sep 11 2000 olh@suse.de
- add video=platinumfb:cmode:8 to System.bin, prevents garbage
* Sun Sep 10 2000 olh@suse.de
- update to 0.0.6, update yaboot to 0.8
* Thu Jul 20 2000 olh@suse.de
- update lilo to 0.0.3
* Wed Jul 19 2000 olh@suse.de
- update lilo to 0.0.2, adapt quik
* Thu Jul 13 2000 olh@suse.de
- update README and System.bin
* Wed Jul 12 2000 olh@suse.de
- initial ppc release
